@@ -175,7 +175,7 @@ def featureExpressionSig(cluster1, projectionName, featureNumber, alpha, mu=0):
     return T, testT
 
 
-def BonferroniCorrectedDifferenceMeans(cluster1, cluster2, alpha, varName):
+def BonferroniCorrectedDifferenceMeans(cluster1, cluster2, alpha, varName, verbose=0):
     """
     Creates Bonferroni corrected Confidence intervals for the difference of the means of cluster1 and cluster2
     :param cluster1: Anndata containing cluster1 cells
@@ -211,14 +211,16 @@ def BonferroniCorrectedDifferenceMeans(cluster1, cluster2, alpha, varName):
         plusminus[0, i] = diff - scale
         plusminus[1, i] = diff + scale
         if plusminus[0, i] < 0 and plusminus[1, i] < 0:
-            print('Gene Name: {0} Mean Difference: {1} Low: {2} High {3}'.format(cluster1.var[varName][i], diff,
-                                                                                 plusminus[0, i], plusminus[1, i]))
+            if verbose is 0:
+                print('Gene Name: {0} Mean Difference: {1} Low: {2} High {3}'.format(cluster1.var[varName][i], diff,
+                                                                                     plusminus[0, i], plusminus[1, i]))
             gene = cluster1.var[varName][i]
             list1.append(gene)
 
         if plusminus[0, i] > 0 and plusminus[1, i] > 0:
-            print('Gene Name: {0} Mean Difference: {1} Low: {2} High {3}'.format(cluster1.var[varName][i], diff,
-                                                                                 plusminus[0, i], plusminus[1, i]))
+            if verbose is 0:
+                print('Gene Name: {0} Mean Difference: {1} Low: {2} High {3}'.format(cluster1.var[varName][i], diff,
+                                                                                     plusminus[0, i], plusminus[1, i]))
             gene = cluster1.var[varName][i]
             list1.append(gene)
 
@@ -279,18 +281,18 @@ def projectionDriver(patterns_filtered, cluster1, cluster2, alpha, varName, feat
         plusminus[0, i] = diff - scale
         plusminus[1, i] = diff + scale
         if plusminus[0, i] < 0 and plusminus[1, i] < 0:
-            print('Gene Name: {0} Mean Difference: {1} Low: {2} High {3}'.format(cluster1.var[varName][i], diff,
-                                                                                 plusminus[0, i], plusminus[1, i]))
+            # print('Gene Name: {0} Mean Difference: {1} Low: {2} High {3}'.format(cluster1.var[varName][i], diff,
+            #                                                                     plusminus[0, i], plusminus[1, i]))
             gene = cluster1.var[varName][i]
             list1.append(gene)
 
         if plusminus[0, i] > 0 and plusminus[1, i] > 0:
-            print('Gene Name: {0} Mean Difference: {1} Low: {2} High {3}'.format(cluster1.var[varName][i], diff,
-                                                                                 plusminus[0, i], plusminus[1, i]))
+            # print('Gene Name: {0} Mean Difference: {1} Low: {2} High {3}'.format(cluster1.var[varName][i], diff,
+            #                                                                    plusminus[0, i], plusminus[1, i]))
             gene = cluster1.var[varName][i]
             list1.append(gene)
 
-    standardBon = BonferroniCorrectedDifferenceMeans(cluster1, cluster2, alpha, varName)
+    standardBon = BonferroniCorrectedDifferenceMeans(cluster1, cluster2, alpha, varName, verbose=613)
 
     driverBon = pd.DataFrame(np.transpose(plusminus), index=cluster1.var[varName], columns=['Low', 'High'])
 
